@@ -15,4 +15,12 @@ def make_request(api_key, url, config=None):
     print(data)
     response = r.get(url=url, data=data, headers=headers)
 
-    return response, response.json(), response.status_code
\ No newline at end of file
+    content = response.json()
+    results = []
+    if data["limit"]:
+        for i in range(data['limit']):
+            results.append(content[i])
+            
+
+
+    return response, results, response.status_code
\ No newline at end of file
